pyLBM.elements.Parallelogram
============================

.. currentmodule:: pyLBM.elements

.. autoclass:: Parallelogram

   

   .. HACK -- the point here is that we don't want this to appear in the output, but the autosummary should still generate the pages.
      .. autosummary::
         :toctree:
      
         Parallelogram.distance
         Parallelogram.get_bounds
         Parallelogram.point_inside
         Parallelogram.test_label



   

   .. HACK -- the point here is that we don't want this to appear in the output, but the autosummary should still generate the pages.
      .. autosummary::
         :toctree:
      
         Parallelogram.number_of_bounds

